## GET 查询员工待办列表

GET /api/wkflow/tasks/{employeeCode}/todo

### 请求参数

| 名称           | 位置    | 类型     | 必选  | 说明      |
| ------------ | ----- | ------ | --- | ------- |
| employeeCode | path  | string | 是   | 员工工号    |
| keyword      | query | string | 否   | 模糊查询关键字 |
| filter       | query | string | 否   | 查询条件    |
| orderby      | query | string | 否   | 排序方式    |
| limit        | query | number | 否   | 分页大小    |
| offset       | query | number | 否   | 分页下标    |

### 返回结果

| 状态码 | 状态码含义                                                   | 说明  | 数据模型   |
| --- | ------------------------------------------------------- | --- | ------ |
| 200 | [OK](https://tools.ietf.org/html/rfc7231#section-6.3.1) | 成功  | Inline |

### 返回数据结构

状态码 **200**

| 名称                      | 类型       | 必选    | 约束   | 中文名 | 说明                                                                                                                       |
| ----------------------- | -------- | ----- | ---- | --- | ------------------------------------------------------------------------------------------------------------------------ |
| » errorCode             | null     | true  | none |     | 错误代码                                                                                                                     |
| » errorMessage          | null     | true  | none |     | 错误信息                                                                                                                     |
| » body                  | object   | true  | none |     | 返回内容                                                                                                                     |
| »» totalCount           | integer  | true  | none |     | 代办个数                                                                                                                     |
| »» list                 | [object] | true  | none |     | 待办列表                                                                                                                     |
| »»» baseBOId            | integer  | false | none |     | 关联业务对象ID                                                                                                                 |
| »»» modelId             | integer  | false | none |     | 工作流模型ID                                                                                                                  |
| »»» stepId              | integer  | false | none |     | 工作流步骤ID                                                                                                                  |
| »»» createdTime         | string   | false | none |     | 创建时间                                                                                                                     |
| »»» taskId              | string   | false | none |     | 待办任务单号                                                                                                                   |
| »»» approveMode         | string   | false | none |     | 审批方式<br />    PROGRESSIVE("逐级审批"),<br />    MULTI_TASK("会签"),<br />    MULTI_CANDIDATE("或签"),<br />    SEQUENCE("依次审批"); |
| »»» taskType            | string   | false | none |     | 任务类型<br /> Action("审批"),<br /> Task("任务"),                                                                               |
| »»» requestType         | string   | false | none |     | 流程类型                                                                                                                     |
| »»» processInstanceId   | string   | false | none |     | 流程单号                                                                                                                     |
| »»» name                | string   | false | none |     | 待办名称                                                                                                                     |
| »»» systemTaskName      | string   | false | none |     | 系统任务名称                                                                                                                   |
| »»» processName         | string   | false | none |     | 流程名称                                                                                                                     |
| »»» summary             | string   | false | none |     | 任务摘要                                                                                                                     |
| »»» processSummary      | string   | false | none |     | 流程摘要                                                                                                                     |
| »»» workStepDescription | string   | false | none |     | 工作流步骤描述                                                                                                                  |
| »»» initiator           | object   | false | none |     | 流程发起人                                                                                                                    |
| »»»» code               | string   | true  | none |     | 工号                                                                                                                       |
| »»»» fullName           | string   | true  | none |     | 姓名                                                                                                                       |
| »»» employee            | object   | false | none |     | 流程关联员工                                                                                                                   |
| »»»» code               | string   | true  | none |     | 工号                                                                                                                       |
| »»»» fullName           | string   | true  | none |     | 姓名                                                                                                                       |
| »»» assignee            | object   | false | none |     | 任务负责人                                                                                                                    |
| »»»» code               | string   | true  | none |     | 工号                                                                                                                       |
| »»»» fullName           | string   | true  | none |     | 姓名                                                                                                                       |
| »»» candidates          | [object] | false | none |     | 任务候选人列表（适用于或签）                                                                                                           |
| »»»» code               | string   | false | none |     | 工号                                                                                                                       |
| »»»» fullName           | string   | false | none |     | 姓名                                                                                                                       |
| »»» approvalStatus      | string   | false | none |     | 处理状态<br />    TO_BE_APPROVED("待审批")                                                                                      |
| »»» h5Url               | string   | false | none |     | H5页面链接                                                                                                                   |
| »»» pcUrl               | string   | false | none |     | PC端链接                                                                                                                    |



### 获取待办计数

#### 概述：

- 用于获取员工的待办数量

#### 接口版本：

|版本号|制定人|制定日期|修订日期|
|:----    |:---|:----- |-----   |
|1.0.0 |张毅彬  |2023-03-07 |   |

#### 请求URL:

- /api/wkflow/tasks/{employeeCode}/todo/count

#### 请求方式：

- GET


#### 请求头：

|参数名|是否必须|类型|说明|
|:----    |:---|:----- |-----   |
|Content-Type |是  |string |请求类型： application/json   |


#### 请求参数:

|参数名|是否必须|类型|说明|
|:----    |:---|:----- |-----   |
|employeeCode |是  |string |工号   |

#### 返回示例:

```
{
    "errorCode": null,
    "errorMessage": null,
    "warningMessages": null,
    "body": 1
}
```


#### 返回参数说明:

|参数名|类型|说明|
|:-----  |:-----|-----                           |
|body |long   |待办数量  |

------------



### 获取抄送未确认计数

#### 概述：

- 用于获取员工的未确定的抄送数量

#### 接口版本：

|版本号|制定人|制定日期|修订日期|
|:----    |:---|:----- |-----   |
|1.0.0 |张毅彬  |2023-03-07 |   |

#### 请求URL:

- /api/wkflow/tasks/{employeeCode}/ccTodo/count

#### 请求方式：

- GET


#### 请求头：

|参数名|是否必须|类型|说明|
|:----    |:---|:----- |-----   |
|Content-Type |是  |string |请求类型： application/json   |


#### 请求参数:

|参数名|是否必须|类型|说明|
|:----    |:---|:----- |-----   |
|employeeCode |是  |string |工号   |

#### 返回示例:

```
{
    "errorCode": null,
    "errorMessage": null,
    "warningMessages": null,
    "body": 1
}
```


#### 返回参数说明:

|参数名|类型|说明|
|:-----  |:-----|-----                           |
|body |long   |待确认抄送数量  |