### **读取自定义对象（UDO）数据**

| 请求地址         | /api/udo/udos/{对象名称} （请将{对象名称}改成需要读取的UDO对象名）                                                |
| ------------ | ------------------------------------------------------------------------------------------- |
| 返回格式         | JSON                                                                                        |
| content-type | application/json                                                                            |
| 请求方式         | GET                                                                                         |
| 请求参数         | QUERY 参数 + PATH参数                                                                           |
| 请求举例         | 请求示例：https://open.hrsaas.com/api/udo/udos/临时考勤卡记录?filter=&offset=0&limit=30&orderby=id desc |
| 返回值          | 自定义对象数组                                                                                     |

| 参数      | 类型     | 说明                                                                                                 | 举例      | 必选  |
| ------- | ------ | -------------------------------------------------------------------------------------------------- | ------- | --- |
| offset  | int    | 分页参数起始值                                                                                            | No      |     |
| limit   | int    | 每也最多纪录数                                                                                            | 100     | No  |
| filter  | string | 过滤条件，请参考[ODATA](https://docs.microsoft.com/zh-cn/azure/search/search-query-odata-filter)表达式了解表达式规则 | id eq 2 | No  |
| orderby | string | 排序规则                                                                                               | id desc | No  |

返回值结构

| 属性         | 类型    | 说明        |
| ---------- | ----- | --------- |
| totalCount | long  | 符合条件的纪录条数 |
| list       | UDO[] | 自定义对象数组   |

UDO对象结构

| 属性                | 类型  | 说明                                |
| ----------------- | --- | --------------------------------- |
| userDefinedFields | Map | 属性名为Key,属性值为Value的map结构           |
| udfLinkedBOMap    | Map | 引用属性名为key, 引用对象为value的map结构       |
| subNodes          | Map | 子节点名key, 子节点数据（UDO数组）为value的map结构 |

返回值举例

```json
 "totalCount":1,
      "list":[
         {
            "id":1,
            "version":null,
            "bizDisabled":false,
            "userDefinedFields":{
               "员工":20668,
               "临时考勤卡号":"40329480124",
               "备注":"fsadfjlasdfasf",
               "借用日期":"2020-09-15"
            },
            "udfLinkedBOMap":{
               "员工":{
                  "id":20668,
                  "bizKey":"123456",
                  "label":"老王"
               }
            },
            "subNodes":{

            },
            "nodeName":"临时考勤卡记录"
         }
      ]
```

### 根据ID读取自定义对象（UDO）数据

| 请求地址         | /api/udo/udos/{对象名称}/{id}                                |
| ------------ | -------------------------------------------------------- |
| 返回格式         | JSON                                                     |
| content-type | application/json                                         |
| 请求方式         | GET                                                      |
| 请求参数         | PATH参数                                                   |
| 请求举例         | 请求示例：https://open.hrsaas.com/api/udo/udos/临时考勤卡记录/122235 |
| 返回值          | UDO                                                      |

### 添加自定义对象（UDO）数据

| 请求地址         | /api/udo/udos/{对象名称}                              |
| ------------ | ------------------------------------------------- |
| 返回格式         | JSON                                              |
| content-type | application/json                                  |
| 请求方式         | POST                                              |
| 请求参数         | PATH参数 POST参数 JSON 格式                             |
| 请求举例         | 请求示例：https://open.hrsaas.com/api/udo/udos/临时考勤卡记录 |
| 返回值          | UDO                                               |

请求POST参数说明

| 属性                | 类型  | 说明                                |
| ----------------- | --- | --------------------------------- |
| userDefinedFields | Map | 属性名为Key,属性值为Value的map结构           |
| subNodes          | Map | 子节点名key, 子节点数据（UDO数组）为value的map结构 |

返回数据说明

| 属性              | 类型 | 说明                                               |
| ----------------- | ---- | -------------------------------------------------- |
| userDefinedFields | Map  | 属性名为Key,属性值为Value的map结构                 |
| id          | Long  | UDO记录ID |

请求POST参数示例

```angular2html
{
    "userDefinedFields":{
       "员工":20668,
       "临时考勤卡号":"40329480124",
       "备注":"忘带工卡，申请临时卡",
       "借用日期":"2020-09-15"
    }
}
```

返回RESPONSE

```angular2html
{
    "errorCode": null,
    "errorMessage": null,
    "warningMessages": null,
    "body": {
        "id": 1,
        "version": null,
        "userDefinedFields": {
            "临时考勤卡号": "40329480124",
            "借用日期": "2020-09-15",
            "员工": 11969,
            "备注": "忘带工卡，申请临时卡"
        },
        "udfLinkedBOMap": {
            "员工": {
                "id": 11969,
                "bizKey": "N0144",
                "label": "朱咏梅"
            }
        },
        "subNodes": {},
        "nodeName": "临时考勤卡记录"
    }
}
```

### 修改自定义对象（UDO）数据

| 请求地址         | /api/udo/udos/{对象名称}/{id}                           |
| ------------ | --------------------------------------------------- |
| 返回格式         | JSON                                                |
| content-type | application/json                                    |
| 请求方式         | PUT                                                 |
| 请求参数         | PATH参数 PUT参数 JSON 格式                                |
| 请求举例         | 请求示例：https://open.hrsaas.com/api/udo/udos/临时考勤卡记录/1 |
| 返回值          | UDO                                                 |

请求PUT参数说明

| 属性              | 类型 | 说明                                               |
| ----------------- | ---- | -------------------------------------------------- |
| userDefinedFields | Map  | 属性名为Key,属性值为Value的map结构                 |
| subNodes          | Map  | 子节点名key, 子节点数据（UDO数组）为value的map结构 |

请求PUT参数示例

```angular2html
{
    "userDefinedFields":{
       "员工":20668,
       "临时考勤卡号":"40329480124",
       "备注":"忘带工卡，申请临时卡",
       "借用日期":"2021-09-15"
    }
}
```

### 删除自定义对象（UDO）数据

| 请求地址         | /api/udo/udos/{对象名称}/{id}                           |
| ------------ | --------------------------------------------------- |
| 返回格式         | JSON                                                |
| content-type | application/json                                    |
| 请求方式         | DELETE                                                 |
| 请求参数         | PATH参数                              |
| 请求举例         | 请求示例：https://open.hrsaas.com/api/udo/udos/临时考勤卡记录/1 |
| 返回值          | NULL                                                 |